Class: RailsAiBridge::Registry::DeprecatedEntry
- Inherits:
-
Data
- Object
- Data
- RailsAiBridge::Registry::DeprecatedEntry
- Defined in:
- lib/rails_ai_bridge/registry/tile_manifest.rb
Overview
Deprecation redirect entry for a renamed or moved skill.
Instance Attribute Summary collapse
-
#message ⇒ String
readonly
Human-readable deprecation message.
-
#moved_to ⇒ String
readonly
Name of the skill this has been moved to.
-
#removed_in ⇒ String?
readonly
Version in which this alias will be removed.
Instance Method Summary collapse
-
#removed_in? ⇒ Boolean
:reek:NilCheck.
Instance Attribute Details
#message ⇒ String (readonly)
Returns human-readable deprecation message.
33 34 35 36 37 |
# File 'lib/rails_ai_bridge/registry/tile_manifest.rb', line 33 DeprecatedEntry = Data.define(:moved_to, :message, :removed_in) do # @return [Boolean] # :reek:NilCheck def removed_in? = !removed_in.nil? end |
#moved_to ⇒ String (readonly)
Returns name of the skill this has been moved to.
33 34 35 36 37 |
# File 'lib/rails_ai_bridge/registry/tile_manifest.rb', line 33 DeprecatedEntry = Data.define(:moved_to, :message, :removed_in) do # @return [Boolean] # :reek:NilCheck def removed_in? = !removed_in.nil? end |
#removed_in ⇒ String? (readonly)
Returns version in which this alias will be removed.
33 34 35 36 37 |
# File 'lib/rails_ai_bridge/registry/tile_manifest.rb', line 33 DeprecatedEntry = Data.define(:moved_to, :message, :removed_in) do # @return [Boolean] # :reek:NilCheck def removed_in? = !removed_in.nil? end |
Instance Method Details
#removed_in? ⇒ Boolean
:reek:NilCheck
36 |
# File 'lib/rails_ai_bridge/registry/tile_manifest.rb', line 36 def removed_in? = !removed_in.nil? |