Module: RailsAiBridge::Registry::GitRunner
- Included in:
- DefaultGitRunner
- Defined in:
- lib/rails_ai_bridge/registry/skill_source_resolver.rb
Overview
Interface for git operations, allowing test injection.
Implementations should provide methods to clone and pull git repositories.
Instance Method Summary collapse
-
#checkout_ref(_path, _ref) ⇒ void
Checks out a specific git ref inside a local repository directory.
-
#clone_repo(_url, _dest) ⇒ void
Clones a remote repository to a local directory path.
-
#current_commit(_path) ⇒ String
Returns the current HEAD commit SHA for the repository at
_path. -
#pull_repo(_path) ⇒ void
Pulls latest changes inside a local repository directory.
Instance Method Details
#checkout_ref(_path, _ref) ⇒ void
This method returns an undefined value.
Checks out a specific git ref inside a local repository directory.
40 41 42 |
# File 'lib/rails_ai_bridge/registry/skill_source_resolver.rb', line 40 def checkout_ref(_path, _ref) raise NotImplementedError end |
#clone_repo(_url, _dest) ⇒ void
This method returns an undefined value.
Clones a remote repository to a local directory path.
21 22 23 |
# File 'lib/rails_ai_bridge/registry/skill_source_resolver.rb', line 21 def clone_repo(_url, _dest) raise NotImplementedError end |
#current_commit(_path) ⇒ String
Returns the current HEAD commit SHA for the repository at _path.
49 50 51 |
# File 'lib/rails_ai_bridge/registry/skill_source_resolver.rb', line 49 def current_commit(_path) raise NotImplementedError end |
#pull_repo(_path) ⇒ void
This method returns an undefined value.
Pulls latest changes inside a local repository directory.
30 31 32 |
# File 'lib/rails_ai_bridge/registry/skill_source_resolver.rb', line 30 def pull_repo(_path) raise NotImplementedError end |